@@ -17,7 +17,7 @@ void exit_row_callback(GtkWidget *widget, gint row, gint, GdkEventButton *, gpoi
 void exit_dialog_ok_callback(GtkWidget *widget, gpointer data);
 void exit_dialog_cancel_callback(GtkWidget *widget, gpointer data);
 void exit_dialog_close_callback(GtkWidget *widget, gpointer data);
-void exit_callback(GtkWidget *widget, gpointer data);
+int exit_callback(GtkWidget *widget, gpointer data);
 void help_callback(GtkWidget *widget, gpointer data);
 void item_help_callback(GtkWidget *widget, gpointer data);
 void about_callback(GtkWidget *widget, gpointer data);
